==> jc-1.4.0.tar.gz: gnu/java/nio/VMSelector.h <==
// public final class gnu.java.nio.VMSelector

// class file dependencies
// @dep_class 4efb68dbb807c30e gnu_java_nio_VMSelector
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_nio_VMSelector_H_
#define _JC_gnu_java_nio_VMSelector_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_nio_VMSelector$sub_refs	_jc_gnu_java_nio_VMSelector$sub_refs;
typedef struct _jc_gnu_java_nio_VMSelector$sub_nonrefs	_jc_gnu_java_nio_VMSelector$sub_nonrefs;
typedef struct _jc_gnu_java_nio_VMSelector$refs	_jc_gnu_java_nio_VMSelector$refs;
typedef struct _jc_gnu_java_nio_VMSelector$nonrefs	_jc_gnu_java_nio_VMSelector$nonrefs;
typedef struct _jc_gnu_java_nio_VMSelector$object	_jc_gnu_java_nio_VMSelector$object;

typedef const struct _jc_gnu_java_nio_VMSelector$vmethods	_jc_gnu_java_nio_VMSelector$vmethods;
typedef const struct _jc_gnu_java_nio_VMSelector$vtable	_jc_gnu_java_nio_VMSelector$vtable;
typedef const struct _jc_gnu_java_nio_VMSelector$vtype	_jc_gnu_java_nio_VMSelector$vtype;

// Constructors
extern void _jc_gnu_java_nio_VMSelector$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_nio_VMSelector$object *);

// Static methods
extern void _jc_gnu_java_nio_VMSelector$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern jint _jc_gnu_java_nio_VMSelector$method$select$5ad06bafd64425f3(_jc_env *, struct _jc_int_array *, struct _jc_int_array *, struct _jc_int_array *, jlong);

// Virtual methods structure
struct _jc_gnu_java_nio_VMSelector$vmethods {
};

// Vtable
struct _jc_gnu_java_nio_VMSelector$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_nio_VMSelector$vmethods	gnu_java_nio_VMSelector;
};

// Vtype
struct _jc_gnu_java_nio_VMSelector$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_VMSelector$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_VMSelector$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_VMSelector$refs {
    _jc_gnu_java_nio_VMSelector$sub_refs	gnu_java_nio_VMSelector;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_VMSelector$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_VMSelector$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_nio_VMSelector$sub_nonrefs	gnu_java_nio_VMSelector;
};

// Object instance structure
struct _jc_gnu_java_nio_VMSelector$object {
	_jc_gnu_java_nio_VMSelector$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_VMSelector$vtype	*vtype;
	_jc_gnu_java_nio_VMSelector$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_VMSelector$vtype _jc_gnu_java_nio_VMSelector$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_VMSelector, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_VMSelector$class_object;

#endif	/* _JC_gnu_java_nio_VMSelector_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/VMSelector.h <==
// public final class gnu.java.nio.VMSelector

// class file dependencies
// @dep_class 4efb68dbb807c30e gnu_java_nio_VMSelector
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_nio_VMSelector_H_
#define _JC_gnu_java_nio_VMSelector_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_nio_VMSelector$sub_refs	_jc_gnu_java_nio_VMSelector$sub_refs;
typedef struct _jc_gnu_java_nio_VMSelector$sub_nonrefs	_jc_gnu_java_nio_VMSelector$sub_nonrefs;
typedef struct _jc_gnu_java_nio_VMSelector$refs	_jc_gnu_java_nio_VMSelector$refs;
typedef struct _jc_gnu_java_nio_VMSelector$nonrefs	_jc_gnu_java_nio_VMSelector$nonrefs;
typedef struct _jc_gnu_java_nio_VMSelector$object	_jc_gnu_java_nio_VMSelector$object;

typedef const struct _jc_gnu_java_nio_VMSelector$vmethods	_jc_gnu_java_nio_VMSelector$vmethods;
typedef const struct _jc_gnu_java_nio_VMSelector$vtable	_jc_gnu_java_nio_VMSelector$vtable;
typedef const struct _jc_gnu_java_nio_VMSelector$vtype	_jc_gnu_java_nio_VMSelector$vtype;

// Constructors
extern void _jc_gnu_java_nio_VMSelector$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_nio_VMSelector$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_java_nio_VMSelector$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_nio_VMSelector$method$select$5ad06bafd64425f3(_jc_env *, struct _jc_int_array *, struct _jc_int_array *, struct _jc_int_array *, jlong) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_nio_VMSelector$vmethods {
};

// Vtable
struct _jc_gnu_java_nio_VMSelector$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_nio_VMSelector$vmethods	gnu_java_nio_VMSelector;
};

// Vtype
struct _jc_gnu_java_nio_VMSelector$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_VMSelector$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_VMSelector$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_VMSelector$refs {
    _jc_gnu_java_nio_VMSelector$sub_refs	gnu_java_nio_VMSelector;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_VMSelector$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_VMSelector$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_nio_VMSelector$sub_nonrefs	gnu_java_nio_VMSelector;
};

// Object instance structure
struct _jc_gnu_java_nio_VMSelector$object {
	_jc_gnu_java_nio_VMSelector$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_VMSelector$vtype	*vtype;
	_jc_gnu_java_nio_VMSelector$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_VMSelector$vtype _jc_gnu_java_nio_VMSelector$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_VMSelector, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_VMSelector$class_object;

#endif	/* _JC_gnu_java_nio_VMSelector_H_ */
